% for analysis of behavioural results of change detection in
% Experiment 2
% published in Southwell et al (2016) Philosophical
% Transactions of the Royal Society B
%
% i) HR & FA rate
% ii) RT
% iii) d'
% 
% Rosy Southwell 2016-01
% ________________________________________
clearvars -except 'resmatALL'

% sort sub/conds and do summary stats
if ~exist('resmatALL','var')
load resmatALL.mat
end
subs=unique(resmatALL(:,1));
cond1={'CA','CD'};
cond1_i={'NCa','CA'; 'NCd','CD'};
cond2={'REG','RAND'};
cols={'subject','blockno','trialno','scene','distractor','result','istgt','rt','rt_o','stimID', 'globalCounter'};
summaryHeader={'subject','mean RT','std RT','SE RT', 'hits','false alarms','tgt','notgt','dprime'};
sortRes=struct;


% add a numeric column on th RHS of submatALL which will be used later for
% indexing back into submatALL.
if size(resmatALL,2)==10
resmatALL=[resmatALL [1:length(resmatALL)]'];
end

for si=1:length(subs)
    s=subs(si);
    subRes = resmatALL(resmatALL(:,1)==s,:);
    ccount=0;
    for c1=1:length(cond1)
        c1Res=subRes(ceil(subRes(:,4)/2)==c1,:);
        for c2=1:length(cond2)
            ccount=ccount+1;
            c12Res=c1Res(c1Res(:,5)==(c2-1),:);
            
            %% summary stats & remove outliers
            c12Res(:,9)=fOutliers(c12Res(:,8),2);
            % put outlier removed RT back in main data matrix
            resmatALL(c12Res(:,11),9)=c12Res(:,9);
            
            mrt = nanmean(c12Res(:,9));
            stdrt = nanstd(c12Res(:,9));
            sert = stdrt/sqrt(length(c12Res));
            
            ht = sum(c12Res(:,6)==1);
            fa = sum(c12Res(:,6)<0);
            tgt = sum(c12Res(:,7)==1);
            ntgt = sum(c12Res(:,7)==0);
            
            dp = dprime(ht,fa,tgt,ntgt,0);
            
            sortRes(c1,c2).sub{si}=c12Res;
            sortRes(c1,c2).summary(s,:) = [s mrt stdrt sert ht fa tgt ntgt dp];
            sortRes(c1,c2).condition = [cond1{c1} ' ' cond2{c2}];
            sortRes(c1,c2).summaryHeader = summaryHeader;
            sortRes(c1,c2).resultsHeader = cols;
            
            % data shaped for spss
            spssRT(s,ccount)=mrt;
            spssDP(s,ccount)=dp;
        end
    end
end

%% find grand averages and errorbars for plotting
ccount=0;
for c1=1:length(cond1)
    for c2=1:length(cond2)
        ccount = ccount+1;
        gmeanRT = mean(sortRes(c1,c2).summary(:,2));
        gseRT = std(sortRes(c1,c2).summary(:,2))/sqrt(length(subs));
        gdp = mean(sortRes(c1,c2).summary(:,9));
        gSEdp = std(sortRes(c1,c2).summary(:,9))/sqrt(length(subs));
        
        groupRes(ccount,:)=[gmeanRT gseRT gdp gSEdp];
        conditions{ccount}=[cond1{c1} ' ' cond2{c2}];
    end
end

%% plots

% number is the font size, for example, if I want size 12 then:
set(0,'defaultAxesFontSize', 12)
set(0,'defaultLineLineWidth',0.5)
barcols=[255 158 0; 158 95 0]/255;

f(1)=figure(1)
% barwitherr(groupRes(:,2),groupRes(:,1),'FaceColor',[1 1 1]);
[ hb,he]=errorbar_groups([groupRes(1:2,1) groupRes(3:4,1)],[groupRes(1:2,2) groupRes(3:4,2)],...
    'FigID',gcf,'bar_width',0.7,...
    'bar_colors',barcols,'errorbar_width',1,'optional_bar_arguments',{'EdgeColor','k'});
set(gca,'XTickLabel',cond1)
ylabel('mean RT (ms)')
set(gcf,'Position',[176   406   200   200])
set(gca,'TickLabelInterpreter','none')
set(gca,'YLim',[550,800])
% text(1.25,0.3,['p = ' num2str(p)])

f(2)=figure(2)
[ hb,he]=errorbar_groups([groupRes(1:2,3) groupRes(3:4,3)],[groupRes(1:2,4) groupRes(3:4,4)],'FigID',gcf,'bar_width',0.7,...
    'bar_colors',barcols,'errorbar_width',1,'optional_bar_arguments',{'EdgeColor','k'});

set(gca,'XTickLabel',cond1);
ylabel('mean d'' ')
set(gcf,'Position',[676   406    200 200])
set(gca,'TickLabelInterpreter','none')
set(gca,'YLim',[0.5,3])

